# flo

![flo](https://upload.wikimedia.org/wikipedia/en/8/84/Flo_from_Progressive_Insurance.jpg)

## Install

```bash
pip install "flo @ git+ssh://git@github.com/fkodom/flo.git"

# Install all dev dependencies (tests etc.)
pip install "flo[all] @ git+ssh://git@github.com/fkodom/flo.git"

# Setup pre-commit hooks
pre-commit install
```